<?php
/**
Plugin Name: Post Thumbnail Widget
Plugin URI: http://iworks.pl/wordpress-plugins-post-thumbnail-widget/
Description: Allow to publish post thumbnails on sidebar.
Version: 1.1
Author: Marcin Pietrzak
Author URI: http://iworks.pl/
Donate link: https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=paypal%40iworks%2epl&item_name=Post%20Thumbnail%20Widget&no_shipping=0&no_note=1&tax=0&bn=PP%2dDonationsBF&charset=UTF%2d8
 *
 * Post Thumbnail Widget.
 *
 * PHP version 5
 *
 * @category WordpressPlugin
 * @package  PostThumbnailWidget
 * @author   Marcin Pietrzak <marcin@iworks.pl>
 * @license  http://www.gnu.org/licenses/gpl.html GPL
 * @version  SVN: $Id: post-thumbnail-widget.php 238660 2010-05-08 13:09:08Z iworks $
 * @link     http://iworks.pl/wordpress-plugins-post-thumbnail-widget/
 */

/**
 * PostThumbnailWidget
 *
 * @category WordpressPlugin
 * @package  PostThumbnailWidget
 * @author   Marcin Pietrzak <marcin@iworks.pl>
 * @license  http://www.gnu.org/licenses/gpl.html GPL
 * @version  @package_version@
 * @link     http://iworks.pl/wordpress-plugins-post-thumbnail-widget/
 */
abstract class PostThumbnailWidget
{
    public static $id   = 'post-thumbnail-widget';
    public static $name = 'Post Thumbnail Widget';
    public static $fields_config = array('rss-display', 'rss-excerpt-display');
    public static $fields_widget = array('title', 'limit');

    /**
     * init()
     *
     * @return null
     *
     */
    public function init()
    {
        load_plugin_textdomain(PostThumbnailWidget::$id, PLUGINDIR.'/'.self::$id, self::$id.'/languages', self::$id.'/languages');
        add_filter('the_content_rss', array('PostThumbnailWidget', 'rss'), 600);
        add_filter('the_excerpt_rss', array('PostThumbnailWidget', 'rssExcerpt'), 600);
        add_action('admin_menu', array('PostThumbnailWidget', 'addAdminOptionPage'));
        wp_register_sidebar_widget(self::$id, __(self::$name, self::$id), array('PostThumbnailWidget', 'sidebar'), array('description'=>__('Allow to publish post thumbnails on sidebar and on RSS.'), 'class'=>self::$id));
        wp_register_widget_control(self::$id, __(self::$name, self::$id), array('PostThumbnailWidget', 'options'));
        return;
    } /*  init() */

    /**
     * getPluginOptions()
     *
     * @return array
     *
     */
    public function getPluginOptions()
    {
        if (function_exists('get_site_option')) {
            $options = get_site_option(self::$id);
        } else {
            $options = get_option(self::$id);
        }
        if (!isset($options['plugin-rss-display'])) {
            $options['plugin-rss-display'] = 'on';
        }
        if (!isset($options['plugin-rss-excerpt-display'])) {
            $options['plugin-rss-excerpt-display'] = 'on';
        }
        if (!isset($options['widget-limit'])) {
            $options['widget-limit'] = 1;
        }
        return $options;
    } /*  getPluginOptions() */

    /**
     * addAdminOptionPage()
     *
     * @return null
     *
     */
    public function addAdminOptionPage()
    {
        add_submenu_page('edit.php', 
            __(self::$name, self::$id), 
            __(self::$name, self::$id), 
            9, 
            basename(__FILE__), 
            array('PostThumbnailWidget', 'displayOptions'));
        return;
    } /*  addAdminOptionPage() */

    /**
     * displayOptions()
     *
     * @return null
     *
     */
    public function displayOptions()
    {
        if (isset($_POST['action']) &&($_POST['action'] == 'update')) {
            self::updateOptions();
            echo '<div class="updated">' . "\n"
                . '<p>'
                . '<strong>'
                . __('Settings saved.')
                . '</strong>'
                . '</p>' . "\n"
                . '</div>' . "\n";
        }

        $options = self::getPluginOptions();
        /* Display admin page */
        ?><div class="wrap">
    <h2><?php _e(self::$name . ' Options', self::$id) ?></h2>
    <form method="post" action="">
        <input type="hidden" name="action" value="update" />
        <input type="hidden" name="page_options" value="<?php echo self::$id; ?>" />
        <?php if (function_exists('wp_nonce_field')) wp_nonce_field(self::$id . '_action_update') ?>
        <fieldset class="options">
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row" valign="top"><label for="position"><?php _e('Display post thumbnail in feeds?', self::$id); ?></label></th>
                        <td>
                            <ul>
                                <li><input type="radio" name="<?php echo self::$id; ?>[plugin-rss-display]" id="plugin-rss-display_on"<?php echo ($options['plugin-rss-display'] == 'on')? ' checked="checked"':''; ?> value="on"  /> <label for="plugin-rss-display_on"><?php _e('Yes'); ?></label></li>
                                <li><input type="radio" name="<?php echo self::$id; ?>[plugin-rss-display]" id="plugin-rss-display_off"<?php echo ($options['plugin-rss-display'] == 'off')? ' checked="checked"':''; ?> value="off" /> <label for="plugin-rss-display_off"><?php _e('No'); ?></label></li>
                            </ul>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><label for="position"><?php _e('Display post thumbnail in feeds with excerpt?', self::$id); ?></label></th>
                        <td>
                            <ul>
                                <li><input type="radio" name="<?php echo self::$id; ?>[plugin-rss-excerpt-display]" id="plugin-rss-excerpt-display_on"<?php echo ($options['plugin-rss-excerpt-display'] == 'on')?  ' checked="checked"':''; ?> value="on"  /> <label for="plugin-rss-excerpt-display_on"><?php _e('Yes'); ?></label></li>
                                <li><input type="radio" name="<?php echo self::$id; ?>[plugin-rss-excerpt-display]" id="plugin-rss-excerpt-display_off"<?php echo ($options['plugin-rss-excerpt-display'] == 'off')? ' checked="checked"':''; ?> value="off" /> <label for="plugin-rss-excerpt-display_off"><?php _e('No'); ?></label></li>
                            </ul>
                        </td>
                    </tr>
                </tbody>
            </table>
        </fieldset>
        <p class="submit"><input type="submit" value="<?php _e('Save Changes'); ?>" /></p>
    </form>
    <h2><?php _e('Donation', self::$id); ?></h2>
    <form action="https://www.paypal.com/cgi-bin/webscr" method="post">
        <input type="hidden" name="cmd" value="_donations">
        <input type="hidden" name="business" value="paypal@iworks.pl">
        <input type="hidden" name="item_name" value="<?php echo self::$name; ?>">
        <input type="hidden" name="no_shipping" value="0">
        <input type="hidden" name="no_note" value="1">
        <input type="hidden" name="tax" value="0">
        <input type="hidden" name="bn" value="PP-DonationsBF">
        <input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="Donate">
        <img alt="" border="0" src="https://www.paypal.com/pl_PL/i/scr/pixel.gif" width="1" height="1">
    </form>
</div>
<?php
        return;
    } /*  displayOptions() */

    /**
     * updateOptions()
     *
     * @return null
     *
     */
    public function updateOptions()
    {
        $options = self::getPluginOptions(self::$id);
        $new_options = array();
        if (isset($_POST[ 'page_options'])) {
            check_admin_referer(self::$id . '_action_update');
            foreach (self::$fields_config as $key) {
                $field_name = 'plugin-' . $key;
                if (isset($_POST[ self::$id ][ $field_name ])) {
                    $new_options[ $field_name ] = $_POST[ self::$id ][ $field_name ];
                }
            }
            foreach (self::$fields_widget as $key) {
                $field_name = 'widget-' . $key;
                if (isset($options[ $field_name ])) {
                    $new_options[ $field_name ] = $options[ $field_name ];
                }
            }
        } else {
            foreach (self::$fields_config as $key) {
                $field_name = 'plugin-' . $key;
                if (isset($options[ $field_name ])) {
                    $new_options[ $field_name ] = $options[ $field_name ];
                }
            }
            foreach (self::$fields_widget as $key) {
                $field_name = 'widget-' . $key;
                if (isset($_POST[ self::$id ][ $field_name ])) {
                    $new_options[ $field_name ] = $_POST[ self::$id ][ $field_name ];
                }
            }
        }
        if (function_exists('update_site_option') &&(function_exists('is_site_admin') && is_site_admin())) {
            update_site_option(self::$id, $new_options);
        } else {
            update_option(self::$id, $new_options);
        }
        return;
    } /*  updateOptions() */

    /**
     * show()
     *
     * @return null
     *
     */
    public function show()
    {
        $options = get_option(self::$id);
        query_posts('meta_key=_thumbnail_id&orderby=rand');
        $limit = 1;

        if (isset($options['widget-limit']) and preg_match('/^\d+$/', $options['widget-limit'])) {
            $limit = $options['widget-limit'];
        }

        global $more;
        $more = 0;
        print '<ol>';
        while (have_posts() and $limit) {
            the_post();
            printf('<li><a href="%s" title="%s">%s</a></li>', 
                get_permalink(), 
                the_title('', '', false), 
                get_the_post_thumbnail(get_the_ID()));
            $limit--;
        }
        print '</ol>';
        wp_reset_query();
        return;
    } /*  show() */

    /**
     * sidebar()
     *
     * @var string
     *
     * @return null
     *
     */
    public function sidebar($args)
    {
        extract($args);
        $options = get_option(self::$id);
        echo $before_widget;
        if (isset($options['widget-title']) && $options['widget-title']) {
            print($before_title . $options['widget-title'] . $after_title);
        }
        self::show();
        echo $after_widget;
    } /* sidebar() */

    /**
     * options()
     *
     * @return null
     *
     */
    public function options()
    {
        if ($_POST[self::$id]) {
            self::updateOptions();
        }
        $options = self::getPluginOptions(self::$id);
        /* begin options */
        echo '<div class="widget-content">';
        /* title */
        echo '<p><label for="'.self::$id.'-widget-title">' . __('Title:') .'</label>';
        echo '<input type="text" value="'.$options['widget-title'].'" name="'.self::$id.'[widget-title]" id="'.self::$id.'-widget-title" class="widefat"></p>';
        /* number */
        echo '<p><label for="'.self::$id.'-widget-limit">' . __('How many items would you like to display?') .'</label> ';
        echo '<input type="text" value="'.$options['widget-limit'].'" name="'.self::$id.'[widget-limit]" id="'.self::$id.'-widget-limit" size="3"></p>';
        /* end options */
        echo '</div>';
        return;
    } /*  options() */

    /**
     * getIcon()
     *
     * @var string
     *
     * @return string
     *
     */
    public function getIcon($mode = 'full')
    {
        global $post;
        $string =($mode == 'full')? '<p>%s</p>':'%s';
        return sprintf($string, get_the_post_thumbnail($post->ID));
    }

    /**
     * isOptionTurnOn()
     *
     * @var string
     *
     * @return bool
     *
     */
    public function isOptionTurnOn($name)
    {
        $options = self::getPluginOptions();
        return (isset($options[ $name ]) && $options[ $name ] == 'on');
    }

    /**
     * rss()
     *
     * @var string
     *
     * @return string
     *
     */
    public function rss($content)
    {
        global $wpdb, $post;
        return (self::isOptionTurnOn('plugin-rss-display'))? self::getIcon() . $content : $content;
    }

    /**
     * rssExcerpt()
     *
     * @var string
     *
     * @return string
     *
     */
    public function rssExcerpt($content)
    {
        global $wpdb, $post;
        return (self::isOptionTurnOn('plugin-rss-excerpt-display'))? self::getIcon('excerpt') . $content : $content;
    }
}
add_action('plugins_loaded', array('PostThumbnailWidget', 'init'));

?>
